JMapFlutterAndroid class
- Inheritance
-
- Object
- PlatformInterface
- JMapFlutterAndroid
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addImageComponent(int id, String byte64String, Size frameSize, Point<num> center, {int cornerRadius = 0})
→ void
-
-
addImageSVGComponent(int id, String svg, Size frameSize, Point<num> center, {int cornerRadius = 0})
→ Future<void>
-
-
addTextComponent(int id, Point<num> center, String text, String? textColor, num? textSize, {double? iconWidth})
→ void
-
-
applyIconStyle(num amenityId, Map<String, String> styles)
→ Future<void>
-
-
applyPathTypeStyle(num pathTypeId, Map<String, String> styles)
→ Future<void>
-
-
buildView(PlatformViewCreatedCallback onPlatformViewCreated, JMapConfig mapConfig)
→ Widget
-
-
changeFloor(int floorId)
→ Future<void>
-
-
clearWayfindingPath()
→ void
-
-
destroy()
→ Future<void>
-
-
disableRotationGestures()
→ void
-
-
disableScaleGestures()
→ void
-
-
dispose()
→ void
-
inherited
-
drawNavigationPath(num startWaypointId, num endWaypointId, String? colorHex, JMapAccessibility? accessibility)
→ Future<void>
-
-
enableLayerInteractivity(List<JMapMapLayer> layers)
→ void
-
-
enableRotationGestures()
→ void
-
-
enableScaleGestures()
→ void
-
-
ensureChannelInitialized()
→ MethodChannel
-
-
fitBoundsInView(Rect rect, double animationDuration)
→ Future<void>
-
-
fitMapInLayer(String layerName)
→ Future<void>
-
-
getAllAmenities()
→ Future<List<JMapAmenity>?>
-
-
getAllAmenitiesByName(String name)
→ Future<List<JMapAmenity>?>
-
-
getAllDestinations()
→ Future<List<JMapDestination>?>
-
-
getAllPathTypes()
→ Future<List<JMapPathType>?>
-
-
getAllPathTypesByName(String name)
→ Future<List<JMapPathType>?>
-
-
getAllZones()
→ Future<List<JMapZone>?>
-
-
getAmenitiesByGeofenceId(int id)
→ Future<List<JMapAmenity>?>
-
-
getAmenitiesInZone(String name)
→ Future<List<JMapAmenity>?>
-
-
getCurrentBuilding()
→ Future<JMapBuilding?>
-
-
getCurrentFloor()
→ Future<JMapFloor?>
-
-
getCurrentMap()
→ Future<JMapMap?>
-
-
getDestination(String id)
→ Future<JMapDestination?>
-
-
getDestinationsByGeofenceId(int id)
→ Future<List<JMapDestination>?>
-
-
getDestinationsInZone(String name)
→ Future<List<JMapDestination>?>
-
-
getFloorsForCurrentBuilding()
→ Future<List<JMapFloor>?>
-
-
getGeofences()
→ Future<List<JMapGeofence>>
-
-
getNavigationInstructions(num startWaypointId, num endWaypointId, JMapAccessibility? accessibility)
→ Future<List<JMapInstruction>?>
-
-
getPathTypesByGeofenceId(int id)
→ Future<List<JMapPathType>?>
-
-
getWaypointsInZone(String name)
→ Future<List<JMapWaypoint>?>
-
-
hideAllAmenities()
→ Future<void>
-
-
hideAllImageMapLabels()
→ void
-
-
hideAllPathTypes()
→ Future<void>
-
-
hideAllTextMapLabels()
→ void
-
-
highlightDestination(JMapDestination destination, String? colorHex)
→ void
-
-
highlightDestinations(List<JMapDestination> destinations, String? colorHex)
→ void
-
-
highlightUnitsInZone(String name, String colorHex)
→ Future<void>
-
-
init()
→ void
-
This method is called when the plugin is first initialized.
-
initNavigationKit(Map<String, dynamic> options)
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onMapInitialized()
→ Stream<JMapInitializedEvent>
-
-
onTapDetectedOnComponent()
→ Stream<TapDetectedOnComponentEvent>
-
-
onTapDetectOnAmenity()
→ Stream<TapDetectedOnAmenityEvent>
-
-
onTapDetectOnElement()
→ Stream<TapDetectedOnElementEvent>
-
-
onTapDetectOnPathType()
→ Stream<TapDetectedOnPathTypeEvent>
-
-
onTapDetectOnWaypoint()
→ Stream<TapDetectedOnWaypointEvent>
-
-
removeImageComponent(int id)
→ void
-
-
removeUserLocation()
→ Future<void>
-
-
resetAmenityStyle()
→ Future<void>
-
-
resetDestinationStyles(num destinationId)
→ void
-
-
resetIconStyle(num amenityId)
→ void
-
-
resetMapStyle()
→ Future<void>
-
-
resetPathTypeStyle()
→ Future<void>
-
-
resetShapeStyle()
→ Future<void>
-
-
setMapTransform(JMapTransform transform)
→ void
-
-
setMaxScale(num scale)
→ void
-
-
setupUserLocation(Point<num> position, Map<String, String> styles, {int? rotation, int? confidence})
→ Future<void>
-
-
setVisiblePointLabelLimit(int limit)
→ void
-
-
showAllAmenities(JMapDrawableOptions? options)
→ Future<void>
-
-
showAllImageMapLabels(JMapDrawableOptions? options)
→ void
-
-
showAllPathTypes(JMapDrawableOptions? options)
→ Future<void>
-
-
showAllTextMapLabels(JMapDrawableOptions? options)
→ void
-
-
showAmenity(JMapAmenity amenity, JMapDrawableOptions? options)
→ Future<void>
-
-
showPathType(JMapPathType pathType, JMapDrawableOptions? options)
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
unhighlightDestination(JMapDestination destination)
→ void
-
-
updateUserLocation(Point<num> position, {int? rotation, int? confidence})
→ Future<void>
-